@@ -5,12 +5,10 @@ import pandas as pd
 from threading import Thread, Event
 from queue import Queue
 import concurrent.futures
-# from . import cache_query, FileFormat
 from .cache_bgquery import cache_query, FileFormat
+from ._connection import DatabaseConnection
 import dask.dataframe as dd
-from dotenv import load_dotenv
 
-load_dotenv()
 
 TRAIN = 'TRAIN'
 TEST = 'TEST'
@@ -102,6 +100,7 @@ class MLDL:
                 query=f"SELECT row_id FROM `{table}` WHERE len <= {max_length} and token_size >= {min_num_feature}",
                 name=f'{max_length}_{min_num_feature}_{stage}',
                 destination_format=FileFormat.CSV,
+                db_connection=DatabaseConnection(),
             )
             # print(res)
             ddf = dd.read_csv(res['uri'])
